==> imcdatasets_1.2.0.tar.gz: imcdatasets/inst/doc/imcdatasets.R <==
## ----style, echo=FALSE--------------------------------------------------------
knitr::opts_chunk$set(error=FALSE, warning=FALSE, message=FALSE,
                      fig.retina = 0.75)
library(BiocStyle)

## ----library, echo=FALSE------------------------------------------------------
library(cytomapper)
library(SingleCellExperiment)
library(imcdatasets)

## ----list-datasets------------------------------------------------------------
datasets <- listDatasets()
datasets <- as.data.frame(datasets)
datasets$FunctionCall <- sprintf("`%s`", datasets$FunctionCall)
knitr::kable(datasets)

## ----import-dataset-----------------------------------------------------------
sce <- DamondPancreas2019Data(data_type = "sce")
sce

## ----import-images------------------------------------------------------------
images <- DamondPancreas2019Data(data_type = "images")
images

## ----import-masks-------------------------------------------------------------
masks <- DamondPancreas2019Data(data_type = "masks")
masks

## ----on_disk------------------------------------------------------------------
# Create temporary location
cur_path <- tempdir()

masks <- DamondPancreas2019Data(data_type = "masks", on_disk = TRUE,
                                h5FilesPath = cur_path)
masks

## ----access-by-name-----------------------------------------------------------
sce <- DamondPancreas2019_sce()
sce

images <- DamondPancreas2019_images()
images

masks <- DamondPancreas2019_masks()
masks

## ----function-help------------------------------------------------------------
?DamondPancreas2019Data

## ----access-metadata----------------------------------------------------------
DamondPancreas2019_sce(metadata = TRUE)
DamondPancreas2019_images(metadata = TRUE)
DamondPancreas2019_masks(metadata = TRUE)

## ----usage-subset-------------------------------------------------------------
cur_images <- images[1:5]
cur_masks <- masks[1:5]

## ----usage-pixel--------------------------------------------------------------
plotPixels(
    cur_images,
    colour_by = c("CDH", "CD99", "H3"),
    bcg = list(
        CD99 = c(0,2,1),
        CDH = c(0,8,1),
        H3 = c(0,5,1)
    )
)

## ----usage-cell---------------------------------------------------------------
plotCells(
    cur_masks, object = sce,
    img_id = "ImageNumber", cell_id = "CellNumber",
    colour_by = c("CD8a", "PIN"),
    exprs_values = "exprs"
)

## ----usage-outline------------------------------------------------------------
plotPixels(
    cur_images, mask = cur_masks, object = sce,
    img_id = "ImageNumber", cell_id = "CellNumber",
    outline_by = "CellType",
    colour_by = c("H3", "CD99", "CDH"),
    bcg = list(
        CD99 = c(0,2,1),
        CDH = c(0,8,1),
        H3 = c(0,5,1)
    )
)

## ----sessionInfo, echo=FALSE--------------------------------------------------
sessionInfo()

==> imcdatasets_1.4.1.tar.gz: imcdatasets/inst/doc/imcdatasets.R <==
## ----style, echo=FALSE--------------------------------------------------------
knitr::opts_chunk$set(error=FALSE, warning=FALSE, message=FALSE,
                      fig.retina = 0.75)
library(BiocStyle)

## ----library, echo=FALSE------------------------------------------------------
library(cytomapper)
library(SingleCellExperiment)
library(imcdatasets)

## ----list-datasets------------------------------------------------------------
datasets <- listDatasets()
datasets <- as.data.frame(datasets)
datasets$FunctionCall <- sprintf("`%s`", datasets$FunctionCall)
knitr::kable(datasets)

## ----import-dataset-----------------------------------------------------------
sce <- DamondPancreas2019Data(data_type = "sce")
sce

## ----import-images------------------------------------------------------------
images <- DamondPancreas2019Data(data_type = "images")
images

## ----import-masks-------------------------------------------------------------
masks <- DamondPancreas2019Data(data_type = "masks")
masks

## ----on_disk------------------------------------------------------------------
# Create temporary location
cur_path <- tempdir()

masks <- DamondPancreas2019Data(data_type = "masks", on_disk = TRUE,
                                h5FilesPath = cur_path)
masks

## ----function-help------------------------------------------------------------
?DamondPancreas2019Data

## ----access-metadata, eval = FALSE--------------------------------------------
#  DamondPancreas2019_sce(metadata = TRUE)
#  DamondPancreas2019_images(metadata = TRUE)
#  DamondPancreas2019_masks(metadata = TRUE)

## ----access-metadata-future-releases, eval = FALSE----------------------------
#  DamondPancreas2019Data(data_type = "sce", metadata = TRUE)
#  DamondPancreas2019Data(data_type = "images", metadata = TRUE)
#  DamondPancreas2019Data(data_type = "masks", metadata = TRUE)

## ----usage-subset-------------------------------------------------------------
cur_images <- images[1:5]
cur_masks <- masks[1:5]

## ----usage-pixel--------------------------------------------------------------
plotPixels(
    cur_images,
    colour_by = c("CDH", "CD99", "H3"),
    bcg = list(
        CD99 = c(0,2,1),
        CDH = c(0,8,1),
        H3 = c(0,5,1)
    )
)

## ----usage-cell---------------------------------------------------------------
plotCells(
    cur_masks, object = sce,
    img_id = "ImageNumber", cell_id = "CellNumber",
    colour_by = c("CD8a", "PIN"),
    exprs_values = "exprs"
)

## ----usage-outline------------------------------------------------------------
plotPixels(
    cur_images, mask = cur_masks, object = sce,
    img_id = "ImageNumber", cell_id = "CellNumber",
    outline_by = "CellType",
    colour_by = c("H3", "CD99", "CDH"),
    bcg = list(
        CD99 = c(0,2,1),
        CDH = c(0,8,1),
        H3 = c(0,5,1)
    )
)

## ----sessionInfo, echo=FALSE--------------------------------------------------
sessionInfo()
